OC.L10N.register(
    "settings",
    {
    "Private" : "Privado",
    "Local" : "Local",
    "Federated" : "Federado",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando ...",
    "Unable to change password" : "No fue posible cambiar la contraseña",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Groups" : "Grupos",
    "Group list is empty" : "La lista de grupos esta vacía",
    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
    "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
    "You changed your password" : "Cambiaste tu contraseña",
    "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
    "{actor} changed your email address" : "{actor} ha cambiado tu dirección de correo electrónico",
    "You changed your email address" : "Cambiaste tu dirección de correo electrónico",
    "Your email address was changed by an administrator" : "Tu dirección de correo electrónico ha sido cambiada por un administrador",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
    "Settings" : "Configuraciones ",
    "Wrong password" : "Contraseña incorrecta",
    "Saved" : "Guardado",
    "Authentication error" : "Error de autenticación",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
    "Administrator documentation" : "Documentación del adminsitrador",
    "User documentation" : "Documentación del usuario",
    "Invalid SMTP password." : "Constraseña SMTP inválida. ",
    "Email setting test" : "Prueba de ajustes de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
    "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
    "Invalid account" : "Cuenta inválida",
    "Invalid mail address" : "Dirección de correo inválida",
    "Settings saved" : "Se han guardado las configuraciones ",
    "Unable to change full name" : "No fue posible cambiar el nombre completo",
    "Unable to change email address" : "No fue posible cambiar la dirección de correo electrónico",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar tu cuenta de Twitter, publica el siguiente tweet en Twitter (por favor asegúrarte de publicar sin ninguna línea en blanco):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verificar tu sitio Web, agrega el siguiente contendio a tu web-root en '.well-known/CloudIdVerificationCode.txt' (por favor asegurate de que el texto completo este en una sóla línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió tu contraseña el %2$s.",
    "Your password on %s was changed." : "Tu contraseña de %s fue cambiada. ",
    "Your password on %s was reset by an administrator." : "Tu contraseña de %s fue restablecida por un administrador.",
    "Password for %1$s changed on %2$s" : "La contraseña de %1$s fue cambiada en %2$s",
    "Password changed for %s" : "La contraseña fue cambiada para %s",
    "If you did not request this, please contact an administrator." : "Si no lo solicitaste, por favor contacta a un administrador. ",
    "Your email address on %s was changed." : "Tu dirección de correo electrónico en %s fue cambiada. ",
    "Your email address on %s was changed by an administrator." : "Tu dirección de correo electrónico en %s fue cambiada por un adminsitrador. ",
    "Email address for %1$s changed on %2$s" : "La dirección de correo electrónico de %1$s ha cambiado en %2$s",
    "Email address changed for %s" : "La dirección de correo electrónico fue cambiada para %s",
    "The new email address is %s" : "La nueva dirección de correo electrónico es %s",
    "Your %s account was created" : "Tu cuenta %s ha sido creada",
    "Welcome aboard" : "Bienvenido a bordo",
    "Welcome aboard %s" : "Bienvenido a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta %s, puedes agregar, proteger y compartir tus datos.",
    "Set your password" : "Establece tu contraseña",
    "Go to %s" : "Ir a %s",
    "Install Client" : "Instalar el cliente",
    "Apps" : "Aplicaciones",
    "Personal" : "Personal",
    "Administration" : "Administración",
    "Users" : "Usuarios",
    "Additional settings" : "Configuraciones adicionales",
    "Overview" : "Generalidades",
    "Basic settings" : "Configuraciones  básicas",
    "Sharing" : "Compartiendo",
    "Calendar" : "Calendario",
    "Personal info" : "Información Personal",
    "Email server" : "Servidor de correo electrónico",
    "Security & setup warnings" : "Advertencias de seguridad y configuración",
    "Background jobs" : "Trabajos en segundo plano",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificando",
    "Disabled" : "Deshabilitado",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
    "None" : "Ninguno",
    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
    "Allow resharing" : "Permitir volver a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
    "Allow public uploads" : "Permitir cargas públicas",
    "Always ask for a password" : "Siempre pedir una contraseña",
    "Enforce password protection" : "Forzar protección de contraseñas",
    "Exclude groups from sharing" : "Evitar que los grupos compartan",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
    "Enforce expiration date" : "Forzar fecha de expiración",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
    "Default share permissions" : "Permisos predeterminados para compartir",
    "Limit to groups" : "Limitar a grupos",
    "Save changes" : "Guardar cambios",
    "All" : "Todos",
    "No results" : "No hay resultados",
    "Update to {version}" : "Actualizar a {version}",
    "Remove" : "Eliminar",
    "Disable" : "Deshabilitar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visita el sitio web",
    "Report a bug" : "Reporta un detalle",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "Featured" : "Destacado",
    "Icon" : "Ícono",
    "Name" : "Nombre",
    "Version" : "Versión",
    "Level" : "Nivel",
    "Actions" : "Acciones",
    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Rename" : "Renombrar",
    "Revoke" : "Revocar",
    "Google Chrome for Android" : "Google Chrome para Android",
    "This session" : "Esta sesión",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Devices & sessions" : "Dispositivos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
    "App name" : "Nombre de la aplicación",
    "Create new app password" : "Crear una nueva contraseña de aplicación",
    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
    "Login" : "Iniciar sesión",
    "Password" : "Contraseña",
    "Enable" : "Habilitar",
    "Server-side encryption" : "Encripción del lado del servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
    "Cancel" : "Cancelar",
    "Confirm" : "Confirmar",
    "Submit" : "Enviar",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Change password" : "Cambiar contraseña",
    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
    "Details" : "Detalles",
    "No email address set" : "No se ha establecido la dirección de correo electrónico",
    "Help translate" : "Ayuda a traducir",
    "Your phone number" : "Su número telefónico",
    "Your website" : "Tu sitio web",
    "Add" : "Agregar",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Borrar",
    "Display name" : "Nombre a desplegar",
    "Email" : "Correo electrónico",
    "Quota" : "Cuota",
    "Language" : "Idioma",
    "Avatar" : "Avatar",
    "Username" : "Usuario",
    "Group admin for" : "Administrador del grupo para",
    "User backend" : "Backend del usuario",
    "Storage location" : "Úbicación del almacenamiento",
    "Last login" : "Último inicio de sesión",
    "{size} used" : "{size} usado",
    "Delete account" : "Borrar cuenta",
    "Done" : "Terminado",
    "Edit" : "Editar",
    "Show last login" : "Mostrar último inicio de sesión",
    "Send email" : "Enviar correo electrónico",
    "Default quota" : "Cuota predeterminada",
    "Unnamed device" : "Dispositivo sin nombre",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
    "Changelog" : "Bitácora de cambios",
    "Admins" : "Administradores",
    "Group name" : "Nombre del grupo",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Location" : "Ubicación",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Full name" : "Nombre completo",
    "Phone number" : "Número de teléfono",
    "Website" : "Sitio web",
    "Your apps" : "Tus aplicaciones",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "Updates" : "Actualizaciones",
    "App bundles" : "Paquetes de aplicación",
    "Hide" : "Ocultar",
    "Never" : "Nunca",
    "Active users" : "Usuarios activos",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
    "Documentation" : "Documentación",
    "Forum" : "Foro",
    "SSL" : "SSL",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
    "Send mode" : "Modo de envío",
    "Encryption" : "Encripción",
    "From address" : "De la dirección",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Authentication" : "Autenticación",
    "Authentication required" : "Autenticación requerida",
    "Credentials" : "Credenciales",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "All checks passed." : "Pasaron todas las verificaciones. ",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
    "Follow us on Twitter" : "Síguenos en Twitter",
    "Check out our blog" : "Visita nuestro blog",
    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
    "No user supplied" : "No se proporcionó usuario alguno",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
    "Invalid user" : "Usuario inválido",
    "Your username is: %s" : "Tu Usuario es: %s",
    "Logged in user must be a subadmin" : "El usuario firmado debe ser un subadministrador ",
    "Enable all" : "Habilitar todo",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Sync client - {os}" : "Sync client - {os}",
    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
    "Copied!" : "¡Copiado!",
    "Copy" : "Copiar",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
    "Your email address" : "Tu dirección de correo electrónico",
    "Your Twitter handle" : "Tu cuenta de Twitter",
    "Add group" : "Agregar grupo",
    "Show user backend" : "Mostrar backend del usuario",
    "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
    "Not saved" : "No guardado",
    "Twitter" : "Twitter",
    "SMTP Username" : "Usuario SMTP",
    "Set default expiration date" : "Establecer la fecha de expiración predeterminada"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
